abacusai.default_llm — AbacusAI documentation

# abacusai.default_llm

## Classes

`DefaultLlm` | A default LLM.

## Module Contents

class abacusai.default_llm.DefaultLlm(client, name=None, enum=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A default LLM.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name of the LLM.

    - enum (str) – The enum of the LLM.

  name = None
  enum = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict